@@ -17,7 +17,7 @@
 from rockset.api.api_keys_api import APIKeysApi
 from rockset.api.aliases_api import AliasesApi
 from rockset.api.collections_api import CollectionsApi
-from rockset.api.custom_roles__beta_api import CustomRolesBetaApi
+from rockset.api.custom_roles_api import CustomRolesApi
 from rockset.api.documents_api import DocumentsApi
 from rockset.api.integrations_api import IntegrationsApi
 from rockset.api.organizations_api import OrganizationsApi
